<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="危化品品名:" prop="basicName" >
          <el-input disabled v-model.trim="state.form.basicName" ></el-input>
        </el-form-item>
        <el-form-item label="相忌危化品:" prop="hazmatBasicName" >
          <el-input disabled v-model.trim="state.form.tabooBasicName" ></el-input>
        </el-form-item>
        <el-form-item label="仓库:" prop="warehouseName" >
          <el-select
              clearable
              v-model="state.form.warehouseName"
              filterable
              remote
              reserve-keyword
              placeholder="请输入所入仓库"
              remote-show-suffix
              :remote-method="getWareHouseList"
              style="width: 100%"
              @change="selectWareValue"
          >
            <el-option
                v-for="item in state.wareHouseList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="存储柜:" prop="cupboardId" >
          <el-select
              v-model="state.form.cupboardId"
              placeholder="请选择存储柜"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.cupList"
                :key="item.id"
                :label="item.cupboardName"
                :value="item.id"
            />
          </el-select>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {getCupById, getWarehouse} from "@/api/hazardousChemicals/warehouse";
import {handleAvoid} from "@/api/hazardousChemicals/avoid";
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const state = reactive({
  form: {
    id: '',
    tabooBasicName: '',
    warehouseName: '',
    warehouseId: '',
    cupboardId: ''
  },
  formRules:{
    warehouseName: [{ required: true, trigger: "blur", message: '请选择仓库' }],
    cupboardId: [{ required: true, trigger: "blur", message: '请选择存储柜' }],
  },
})


const openDialog = async (value) => {
  await getWareHouseList("")
  await getCupList(value.warehouseId)
  title.value = '相忌报警处理'
  state.form = JSON.parse(JSON.stringify(value));
  dialogVisible.value = true;
}

const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    const param = {
      cupboardId: state.form.cupboardId,
      id: state.form.id,
      warehouseId:state.form.warehouseId
    }
    const res = await handleAvoid(param)
    if(res.code === 200){
      ElMessage({
        type: 'success',
        message: '处理成功'
      });
    }else{
      ElMessage.warning(res.message)
    }
    emit("getList")
    busRef.value.clearValidate();
    reset();
    dialogVisible.value = false;
  }
}
const getWareHouseList = async (val) => {
  let param = {}
  if(val != ""){
    param = {
      name: val
    }
  }else {
    param = {
      pageNum: 1,
      pageSize: 10
    }
  }
  const res = await getWarehouse(param)
  if(res.code == 200){
    state.wareHouseList = res.data.list.map(item => {
      return {
        ...item,
        children: item.warehouseCupboards && item.warehouseCupboards.length>0 ? item.warehouseCupboards : null
      }
    })
  }else{
    ElMessage.warning(res.message)
  }
}
const selectWareValue = (val) => {
  state.form.cupboardId = null
  state.wareHouseList.forEach(item => {
    if(item.name === val){
      state.form.warehouseId = item.id
      getCupList(item.id)
    }
  })
}
const getCupList = async (val) => {
  const res = await getCupById(val)
  if(res.code == 200) {
    state.cupList = res.data
  }else {
    ElMessage.warning(res.message)
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    hazmatBasicName: '',
    warehouseName: '',
    cupboardId: ''
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
